(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7721,        294]*)
(*NotebookOutlinePosition[      8600,        324]*)
(*  CellTagsIndexPosition[      8556,        320]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData["Piper pour mieux d\[EAcute]coder"], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True,
  FontSize->24],

Cell[TextData[
"D\[EAcute]finissons les transformations affines qui codent la \
foug\[EGrave]re de Barnsley (tableau 1 de la lettre n\.ba 20):"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
m1={{0.85,0.04},{-0.04,0.85}};
Q1={0,1.6};
m2={{-0.15,0.28},{0.26,0.24}};
Q2={0,0.44};
m3={{0.2,-0.26},{0.23,0.22}};
Q3={0,1.6};
m4={{0,0},{0,0.16}};
Q4={0,0};\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData[{
  StyleBox["\nPremi\[EGrave]re technique",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10,
    FontWeight->"Bold"],
  StyleBox[
  "\nD\[EAcute]finissons une figure initiale et visualisons-l\[AGrave]:",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
pts={
\t{0.452381, 0.004762}, 
\t{0.452381, 0.22381}, 
\t{0.157143, 0.414286}, 
\t{0.02381,  0.680952}, 
\t{0.02381,  0.928571}, 
\t{0.366667, 1.576191}, 
\t{0.776191, 2.004762}, 
\t{0.995238, 2.109524}, 
\t{0.852381, 1.814286}, 
\t{0.880952, 1.061905}, 
\t{0.995238, 0.652381}, 
\t{0.776191, 0.166667}, 
\t{0.452381, 0.119048}
};\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
Show[Graphics[Line[pts]],
AspectRatio->Automatic,
Axes->True]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData["Chargeons le module IteratedMappings:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["<<IteratedMappings`", "Input",
  CellGroupingRules->"GraphicsGrouping",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData[
"Formons la r\[EAcute]union des transformations affines (op\[EAcute]rateur de \
Hutchinson) et r\[EAcute]it\[EAcute]rons l'application de cet \
op\[EAcute]rateur \[AGrave] la figure:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
Table[Show[Graphics[Line[pts]],
\tPlotRange->All,
\tAspectRatio->Automatic,
\tDisplayFunction->Identity];
IteratedMapping[{AffineMap[m1,Q1],
\t\t\t\t AffineMap[m2,Q2],
\t\t\t\t AffineMap[m3,Q3],
\t\t\t\t AffineMap[m4,Q4]},
\tn,
\tLine[pts],
\tPlotRange->All,
\tAxes->None],{n,0,4}]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData["Assemblons les images obtenues dans un tableau:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
Show[GraphicsArray[%],
GraphicsSpacing->{0.1,0}]

\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData[{
  StyleBox["Deuxi\[EGrave]me technique",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10,
    FontWeight->"Bold"],
  StyleBox[
  "\nD\[EAcute]finissons quatre fonctions correspondant aux transformations:",
    
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
t1[p_]:=m1.p+Q1
t2[p_]:=m2.p+Q2
t3[p_]:=m3.p+Q3
t4[p_]:=m4.p+Q4\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData[
"La fonction suivante permettra de tirer au sort une des transformations:"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["t[p_]:={t1,t2,t3,t4}[[Random[Integer,{1,4}]]][p]", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData[
"La fonction IFS4 (Iterated Functions System \[AGrave] 4 fonctions) permet \
d'obtenir, \[AGrave] partir d'un point initial, n points:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
IFS4[p_, n_]:=
Show[Graphics[Map[Point,NestList[t,p,n]]],
AspectRatio->Automatic,
PlotRange->All]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell["IFS4[{0.452381, 0.004762},28000]", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell[TextData[{
  StyleBox["\n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10],
  StyleBox["Am\[EAcute]liorer la technique en pipant les d\[EAcute]s",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10,
    FontWeight->"Bold"],
  StyleBox[
  "\nOn peut am\[EAcute]liorer la deuxi\[EGrave]me technique en attribuant \
des probabilit\[EAcute]s diff\[EAcute]rentes \[AGrave] chaque transformation. \
Comme l'image finale ne d\[EAcute]pend pas du point initial, \
d\[EAcute]finissons une fonction dont le seul argument sera le nombre d'it\
\[EAcute]rations, c'est-\[AGrave]-dire dans notre cas, le nombre de points de \
l'image finale:",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSize->10]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["\<\
Foug\[EGrave]re[n_] := 
  Show[Graphics[Map[Point,NestList[
    Which[
    (r=Random[Integer,{1,100}])<= 85,m1.#+Q1,
                              r<= 92,m2.#+Q2,
                              r<= 99,m3.#+Q3,
                              r==100,m4.#+Q4]&,
 \t{0,0}, n]],
 AspectRatio->Automatic,
 PlotRange->All]]\
\>", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell["D\[EAcute]codons:", "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell["Foug\[EGrave]re[30000]", "Input",
  AspectRatioFixed->True,
  FontSize->10],

Cell["Avec de la couleur :", "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->10],

Cell[BoxData[{
    \(Foug\[EGrave]re[n_] := 
      Show[Graphics[
          Join[{RGBColor[0.4, 0.7, 0.5]}, 
            Map[Point, 
              NestList[
                Which[\((r = Random[Integer, {1, 100}])\) \[LessEqual] 85, 
                    m1 . # + Q1, r \[LessEqual] 92, m2 . # + Q2, 
                    r \[LessEqual] 99, m3 . # + Q3, r \[Equal] 100, 
                    m4 . # + Q4] &, {0, 0}, n]]], 
          AspectRatio \[Rule] Automatic, 
          PlotRange \[Rule] All]]\), "\[IndentingNewLine]", 
    \(Foug\[EGrave]re[100000]\)}], "Input"]
},
FrontEndVersion->"4.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 738}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{840, 667},
WindowMargins->{{60, Automatic}, {-13, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.5
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 147, 4, 68, "Text",
  Evaluatable->False],
Cell[1855, 56, 217, 5, 44, "Text",
  Evaluatable->False],
Cell[2075, 63, 226, 11, 170, "Input"],
Cell[2304, 76, 385, 14, 90, "Text",
  Evaluatable->False],
Cell[2692, 92, 397, 18, 303, "Input"],
Cell[3092, 112, 128, 6, 75, "Input"],
Cell[3223, 120, 127, 3, 44, "Text",
  Evaluatable->False],
Cell[3353, 125, 119, 3, 37, "Input",
  CellGroupingRules->"GraphicsGrouping"],
Cell[3475, 130, 272, 6, 44, "Text",
  Evaluatable->False],
Cell[3750, 138, 348, 15, 246, "Input"],
Cell[4101, 155, 137, 3, 44, "Text",
  Evaluatable->False],
Cell[4241, 160, 117, 7, 94, "Input"],
Cell[4361, 169, 393, 15, 67, "Text",
  Evaluatable->False],
Cell[4757, 186, 130, 7, 94, "Input"],
Cell[4890, 195, 166, 5, 44, "Text",
  Evaluatable->False],
Cell[5059, 202, 107, 2, 37, "Input"],
Cell[5169, 206, 224, 5, 44, "Text",
  Evaluatable->False],
Cell[5396, 213, 164, 7, 94, "Input"],
Cell[5563, 222, 91, 2, 37, "Input"],
Cell[5657, 226, 821, 23, 136, "Text",
  Evaluatable->False],
Cell[6481, 251, 381, 13, 208, "Input"],
Cell[6865, 266, 97, 3, 44, "Text",
  Evaluatable->False],
Cell[6965, 271, 81, 2, 37, "Input"],
Cell[7049, 275, 100, 3, 44, "Text",
  Evaluatable->False],
Cell[7152, 280, 565, 12, 224, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

